@@ -38,8 +38,8 @@ def handle_exception(exc):
     logger.exception(exc)
 
     if isinstance(exc, errors.FuelCannotFindCommandError):
-        print_err(messages.header)
-        print_err(messages.install_required_packages)
+        print_err(messages.HEADER)
+        print_err(messages.INSTALL_REQUIRED_PACKAGES)
 
     elif isinstance(exc, errors.ValidationError):
         print_err('Validation failed')
@@ -52,6 +52,12 @@ def handle_exception(exc):
     sys.exit(-1)
 
 
+def decode_string(string):
+    """Custom type for add_argument method
+    """
+    return unicode(string, 'utf-8')
+
+
 def parse_args():
     """Parse arguments and return them
     """
@@ -59,23 +65,33 @@ def parse_args():
         description='fpb is a fuel plugin builder which '
         'helps you create plugin for Fuel')
 
+    #TODO(vsharshov): we should move to subcommands instead of
+    # exclusive group, because in this case we could not
+    # support such behavior [-a xxx | [-b yyy -c zzz]]
     group = parser.add_mutually_exclusive_group(required=True)
 
     group.add_argument(
         '--create', help='create a plugin skeleton',
-        type=str, metavar='plugin_name')
+        type=decode_string, metavar='plugin_name')
     group.add_argument(
         '--build', help='build a plugin',
-        type=str, metavar='path_to_directory')
+        type=decode_string, metavar='path_to_directory')
     group.add_argument(
         '--check', help='check that plugin is valid',
-        type=str, metavar='path_to_directory')
+        type=decode_string, metavar='path_to_directory')
 
     parser.add_argument(
         '--debug', help='enable debug mode',
         action="store_true")
 
-    return parser.parse_args()
+    parser.add_argument(
+        '--package-version', help='which package version to use',
+        type=decode_string)
+
+    result = parser.parse_args()
+    package_version_check(result, parser)
+
+    return result
 
 
 def perform_action(args):
@@ -83,18 +99,24 @@ def perform_action(args):
 
     :param args: argparse object
     """
-
     if args.create:
-        actions.CreatePlugin(args.create).run()
+        actions.CreatePlugin(args.create, args.package_version).run()
         print('Plugin is created')
     elif args.build:
-        actions.BuildPlugin(args.build).run()
+        actions.make_builder(args.build).run()
         print('Plugin is built')
     elif args.check:
         ValidatorManager(args.check).get_validator().validate()
         print('Plugin is valid')
 
 
+def package_version_check(args, parser):
+    """Check exclusive nature of --package-version argument
+    """
+    if (args.build or args.check) and args.package_version:
+        parser.error('--package-version works only with --create')
+
+
 def main():
     """Entry point
     """
